<?php

namespace Teknisa\CNC\Services;
use Teknisa\Libs\Util\Environment;
use Teknisa\CNC\Utilities\UtilCNC;
use Teknisa\CNC\Factories\Cnc01600CadastroEstabelecimentoFactory;

class Cnc01600CadastroEstabelecimentoService {
    
    protected $entityManager;
    protected $factory;
    protected $environment;
    protected $util;
    
    public function __construct (\Doctrine\ORM\EntityManager $entityManager, Environment $environment, Cnc01600CadastroEstabelecimentoFactory $factory, UtilCNC $util) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->factory = $factory;
        $this->util = $util;
    }

    public function getEstabelecParam ($likeConditions) {
        if(isset($likeConditions['ALL_FIELDS'])) {
            $likeConditions['ALL_FIELDS'] = $likeConditions['ALL_FIELDS'][0]['_ALL'];
            $likeConditions['TALL_FIELDS'] = 'F';
        } else {
            $likeConditions['ALL_FIELDS'] = null;
            $likeConditions['TALL_FIELDS'] = 'T';
        }
        
        $result = $this->factory->getEstabelecParam(array(
            ':NRORG' => $this->environment->getNrOrgTrab(),
            ':ALL_FIELDS' => $likeConditions['ALL_FIELDS'],
            ':TALL_FIELDS' => $likeConditions['TALL_FIELDS']
        ));
        
        return $result;
    }

    public function getContaRec () {
        $result = $this->factory->getContaRec();
        return $result;
    }

    public function getTpAjuste () {
        $result = $this->factory->getTpAjuste();
        return $result;
    }

    public function getTpDebito () {
        $result = $this->factory->getTpDebito();
        return $result;
    }

    public function getTpCredito () {
        $result = $this->factory->getTpCredito();
        return $result;
    }

    public function getSeries ($row) {
        $result = $this->factory->getSeries(array(
            ':NRORG'       => $row[0]['value'],
            ':CDINSCESTA'  => $row[1]['value'],
            ':CDINSCMUNI'  => $row[2]['value'],
            ':CDEMPRESA'   => $row[3]['value']
        ));
        return $result;
    }

    public function getAgencias ($row) {
        $result = $this->factory->getAgencias(array(
            ':CDBANCO'   => $row[0]['value'],
            ':CDEMPRESA' => $row[1]['value'],
            ':NRORG'     => $this->environment->getNrOrgTrab()
        ));
        
        return $result;
    }
    
    public function getContas ($row) {
        $result = $this->factory->getContas(array(
            ':CDBANCO'      => $row[0]['value'],
            ':CDAGENCIA'    => $row[1]['value'],
            ':CDEMPRESA'    => $row[2]['value'],
            ':NRORG'        => $this->environment->getNrOrgTrab()
        ));
        
        return $result;
    }

    public function getBancoMasks ($cdbano) {
        $result = $this->factory->getBancoMasks(array(
            ':CDBANCO'  => $cdbano
        ));
        
        return $result;
    }

    public function getEmpresaFilial ($NMFILIAL) {
        $result = $this->factory->getEmpresaFilial(array(
            ':NMFILIAL'  => $NMFILIAL
        ));
        return $result;
    }
    
      public function saveEstabelec ($row) {
        $result = $this->factory->getEmpresaFilial(array(
            ":NRORG"    => $this->environment->getNrOrgTrab(),
            ":CDFILIAL" => $row["CDFILIAL"]
        ));
        $row["CDEMPRESA"] = $result["CDEMPRESA"];
        $row["NRCNPJESTABELEC"] = $result["NRINSJURFILI"];
        $row["CDINSCMUNI"] = $result["CDINSCMUNI"];
        $row["CDINSCESTA"] = $result["CDINSCESTA"];
        
        //Apaga a série relacionada ao estabelecimento 
        //que teve sua filial alterada.
        $row["CDSERIE"] = null;
        
        //Deleta contas correntes relacionadas ao estabelecimento 
        //que teve sua filial alterada.
        $this->factory->deleteEstabelecContcor(array(
            ":NRORG"            => $this->environment->getNrOrgTrab(),
            ":NRESTABELEC"      => $row["NRESTABELEC"],
        ));

        $this->factory->saveEstabelec(array(
            ":NRORG"            => $this->environment->getNrOrgTrab(),
            ":NMESTABELEC"      => $row["NMESTABELEC"],
            ":CDESTABELECEXT"   => $row["CDESTABELECEXT"],
            ":CDFILIAL"         => $row["CDFILIAL"],
            ":NRESTABELEC"      => $row["NRESTABELEC"],
            ":CDEMPRESA"        => $row["CDEMPRESA"],
            ":CDINSCESTA"       => $row["CDINSCESTA"],
            ":CDINSCMUNI"       => $row["CDINSCMUNI"],
            ":CDSERIE"          => $row["CDSERIE"]
        ));

    }
    
    public function saveEstabelecName ($row) {
        $result = $this->factory->getEmpresaFilial(array(
            ":NRORG"    => $this->environment->getNrOrgTrab(),
            ":CDFILIAL" => $row["CDFILIAL"]
        ));
        $row["CDEMPRESA"] = $result["CDEMPRESA"];
        $row["NRCNPJESTABELEC"] = $result["NRINSJURFILI"];
        $row["CDINSCMUNI"] = $result["CDINSCMUNI"];
        $row["CDINSCESTA"] = $result["CDINSCESTA"];
        $this->factory->saveEstabelecName(array(
            ":NRORG"            => $this->environment->getNrOrgTrab(),
            ":NMESTABELEC"      => $row["NMESTABELEC"],
            ":CDESTABELECEXT"   => $row["CDESTABELECEXT"],
            ":CDFILIAL"         => $row["CDFILIAL"],
            ":NRESTABELEC"      => $row["NRESTABELEC"],
            ":CDEMPRESA"        => $row["CDEMPRESA"],
            ":CDINSCESTA"       => $row["CDINSCESTA"],
            ":CDINSCMUNI"       => $row["CDINSCMUNI"]
        ));

    }

    
    public function getFilialParams($row){
        $result = $this->factory->getFilialParams(array(
            ":NRORG"        => $this->environment->getNrOrgTrab(),
            ":CDFILIAL"     => $row[1]['value'],
            ":NRESTABELEC"  => $row[2]['value']
        ));
        return $result;
    
    }

}
