<?php

namespace Teknisa\CNC\Services;

use Zeedhi\Framework\DB\StoredProcedure\Param;

use Teknisa\CNC\Factories\Cnc02200ErrorLogFactory;

class Cnc02200ErrorLogService {
    protected $factory;
    
    public function __construct(Cnc02200ErrorLogFactory $factory) {
        $this->factory = $factory;
    }
    
    public function findAll ($params) {
        return $this->factory->findAll(array(
            ":NRORG"    => $params["NRORG"]
        ));
        
    }
    
    public function find ($params) {
        return $this->factory->find(array(
            ":NRESTABELEC"  => $params["NRESTABELEC"],
            ":NRORG"        => $params["NRORG"]
        ));
    }
    
    public function getDateFromErrorLog ($params) {
        return $this->factory->getDateFromErrorLog(array(
            ":NRESTABELEC" => $params["NRESTABELEC"],
            ":NRORG"       => $params["NRORG"]
        ));
    }
    
    public function runProcFinanc ($row) {
        
        $row["P_SEQESTABELEC"]  = $this->buildInputParam("P_SEQESTABELEC", $row["NRESTABELEC"]);
        $row["P_DTINICIAL"]     = $this->buildInputParam("P_DTINICIAL", $row["DATE"]["DTINICIAL"]);
        $row["P_DTFINAL"]       = $this->buildInputParam("P_DTFINAL", $row["DATE"]["DTFINAL"]);
        $this->factory->runProcFinanc($row);
    }
    
    public function countErrors ($params) {
        $result =  $this->factory->countErrors(array(
            ":NRESTABELEC"  => $params["NRESTABELEC"],
            ":NRORG"        => $params["NRORG"]
        ));
        if ($result > 0)
            throw new \Exception("Não é possível gerar os dados do financeiro pois ainda existem erros não corrigidos. Favor corrigir todos os erros antes de gerar os dados.", 1);
        return "Dados do financeiro gerados com sucesso!";
    }
    
    public function countErrorsForCard ($params) {
        return $this->factory->countErrorsForCard(array(
            ":NRORG"    => $row["NRORG"]
        ));
    }
    
    private function buildInputParam ($paramName, $paramValue) {
        return new Param($paramName, Param::PARAM_INPUT, $paramValue, Param::PARAM_TYPE_STR, strlen($paramValue));
    }
}